@@ -136,13 +136,14 @@ testDbplyrFunctions <- function(connectionDetails, cdmDatabaseSchema) {
     collect()
   expect_gt(personTwice$n, 1)
   
-  tripleJoin <- person %>%
-    left_join(observationPeriod, by = join_by(person_id)) %>%
-    left_join(observationPeriod %>%
-                select(person_id, dummy = observation_period_start_date),
-                by = join_by(person_id)) %>%
-    collect()
-  expect_gt(nrow(tripleJoin), 0)
+  # Skipping until DatabaseConnector 7 or a new dbplyr version. See #271
+  # tripleJoin <- person %>%
+  #   left_join(observationPeriod, by = join_by(person_id)) %>%
+  #   left_join(observationPeriod %>%
+  #               select(person_id, dummy = observation_period_start_date),
+  #             by = join_by(person_id)) %>%
+  #   collect()
+  # expect_gt(nrow(tripleJoin), 0)
   
   # Test row_number ------------------------------------------------------------
   top10PersonsHardWay <- person %>%
